import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="gros_client",
    version="1.0.12",
    author='jax',
    author_email='ming.li@fftai.com',
    license='MIT',
    description="Fourier General Robotics OS - Client Library (python)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/FFTAI/gros_client_py",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=['requests>=2.31.0', 'websocket-client>=1.6.2'],
    python_requires='>=3'
)



from typing import Dict, Any

import requests


class Camera:
    """ 相机

    用于获取视频流状态和视频流
    """

    video_stream_status: bool = None
    video_stream_url: str = None

    def __init__(self, baseurl: str):
        self._baseurl = baseurl
        self.video_stream_status: bool = self._get_video_status().get('data')
        if self.video_stream_status:
            self.video_stream_url: str = f'{self._baseurl}/control/camera'

    def _get_video_status(self) -> Dict[str, Any]:
        response = requests.get(f'{self._baseurl}/control/camera_status')
        return response.json()
